@@ -10,9 +10,9 @@
 #define _BUFFER_H
 
 #include "ZNCString.h"
-#include <vector>
+#include <deque>
 
-using std::vector;
+using std::deque;
 
 class CBufLine {
 public:
@@ -35,7 +35,7 @@ protected:
 	bool	m_bIncNick;
 };
 
-class CBuffer : private vector<CBufLine> {
+class CBuffer : private deque<CBufLine> {
 public:
 	CBuffer(unsigned int uLineCount = 100);
 	~CBuffer();
@@ -43,6 +43,8 @@ public:
 	int AddLine(const CString& sPre, const CString& sPost, bool bIncNick = true);
 	/// Same as AddLine, but if there is already a line with sPre it is replaced.
 	int UpdateLine(const CString& sPre, const CString& sPost, bool bIncNick = true);
+	/// Same as UpdateLine, but does nothing if this exact line already exists
+	int UpdateExactLine(const CString& sPre, const CString& sPost, bool bIncNick = true);
 	bool GetNextLine(const CString& sTarget, CString& sRet);
 	bool GetLine(const CString& sTarget, CString& sRet, unsigned int uIdx) const;
 	bool IsEmpty() const { return empty(); }
